@@ -17,7 +17,7 @@ class IdentityAuthentication(authentication.BaseAuthentication):
         if not email or email not in settings.IDENTITY_WHITELIST:
             return None
         try:
-            user = User.objects.get(email=email)
+            user = User.objects.get(email__iexact=email)
         except User.DoesNotExist:
             raise exceptions.AuthenticationFailed("No such user")
         return (user, None)
@@ -53,7 +53,7 @@ class IdentitySSOAuthentication(authentication.BaseAuthentication):
         user_info = user_info_reply.json()
         email = user_info["user"]["email"]
         user, _ = User.objects.get_or_create(
-            email=email,
+            email__iexact=email,
             defaults={
                 'username': email,
                 'email': email
@@ -90,7 +90,7 @@ class IdentityAPIKeyAuthentication(authentication.BaseAuthentication):
         user_info = user_info_reply.json()
         email = user_info["user"]["email"]
         user, _ = User.objects.get_or_create(
-            email=email,
+            email__iexact=email,
             defaults={
                 'username': email,
                 'email': email
